@@ -50,8 +50,10 @@ nearest_neighbor <- function(mode = "unknown",
     args = args,
     eng_args = NULL,
     mode = mode,
+    user_specified_mode = !missing(mode),
     method = NULL,
-    engine = engine
+    engine = engine,
+    user_specified_engine = !missing(engine)
   )
 }
 
